#! /bin/bash
#
# Copyright (c) 1996 S.u.S.E. Gmbh Fuerth, Germany.  All rights reserved.
#
# Author: Burchard Steinbild <bs@suse.de>, 1996
#         Martin Scherbaum <maddin@suse.de>, 5/1997         
#         Ruediger Oertel <ro@suse.de>, 7/1998

#
# Variables in /etc/rc.config used by this script are: 
#   CREATE_PERLLOCAL_POD
#
# This script calls the scripts:
#   /usr/sbin/perllocal.suse which comes from the package perl
#

#
# check if we are started as root
# only one of UID and USER must be set correctly
#
if test "$UID" != 0 -a "$USER" != root; then
    echo "You must be root to start $0."
    exit 1
fi

#
# SuSEconfig sometimes sets the variable CHECK_NEWPACKAGE. If it is set
# to false, we don't have to do anything.
# 
test "$CHECK_NEWPACKAGE" = false && exit 0

test -f /etc/rc.config || { echo "No /etc/rc.config found." && exit 1 ; }
. /etc/rc.config

# this skript only works in a running system.

test -n "$ROOT" && exit 0

RUN_H2PH="false"

if test "X$GENERATE_PERL_SYSTEM_INCLUDES" = "Xyes" ; then
  # try to see if the kernel includes have changed
  if test -d /usr/include/linux >/dev/null 2>&1 ; then
    echo `cd /usr/include/linux; exec pwd` > /var/adm/SuSEconfig/h2ph_check.tmp
  fi
  test -d /usr/src/linux || { echo "No kernel includes installed"; exit 0 ; }
  echo `rpm -qf /usr/src/linux` >> /var/adm/SuSEconfig/h2ph_check.tmp 2>&1

  if ! cmp /var/adm/SuSEconfig/h2ph_check /var/adm/SuSEconfig/h2ph_check.tmp >/dev/null 2>&1 ; then
    if test -x /usr/bin/h2ph -a -d /usr/include \
      -a ! -e /usr/lib/YaST/.DemoMode  ; then
	echo -n Setting up perl...
	    (
	        cd /usr/include
	        for dir in ./ sys/ linux/ asm/ ; do
		  hasfiles="false"
		  for file in $dir/*.h ; do
		    if [ -f $file ] ; then
		      hasfiles="true"
		      break
		    fi
		  done
		  if [ $hasfiles = "true" ] ; then
		    /usr/bin/h2ph $dir/*.h > /dev/null
		  fi
		done
	    )
	echo done.
    fi
  fi
  mv /var/adm/SuSEconfig/h2ph_check.tmp /var/adm/SuSEconfig/h2ph_check
fi

test -x `which perl` || { echo "Perl not found." && exit 0 ; }

#
# see if we may do any work
#
test -n "$CREATE_PERLLOCAL_POD" -a "$CREATE_PERLLOCAL_POD" = "yes" \
	|| { echo "disabled in rc.config" && exit 1 ; }
	
#
# check if anything to add
#
PERLLOCAL_PATH=`perl -V:installarchlib`

NEEDED="false"

if test -d /var/adm/perl-modules ; then 
	if test /var/adm/perl-modules -nt $PERLLOCAL_PATH/perllocal.pod ; then
		NEEDED="true"
	elif test ! -f $PERLLOCAL_PATH/perllocal.pod ; then
		NEEDED="true"
	fi
fi

#
# now call the working script
#
if "$NEEDED" = "true" ; then
	if test -x /var/adm/SuSEconfig/bin/perllocal.SuSE ; then
		/var/adm/SuSEconfig/bin/perllocal.SuSE
	else
		echo "SuSEconfig.perl: /var/adm/SuSEconfig/bin/perllocal.SuSE not found!"
	fi
fi

#
# end of file SuSEconfig.perl
#
